﻿using System;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.IO.Compression;
using OpenLiveWriter.Api;

namespace FilesForOLW
{
    [WriterPlugin("319f1f53-542f-444f-ae89-0eac3a6adcc9", "File Plugin",
        Description = "This plugin helps with adding files to blogs/pages.",
        HasEditableOptions = false,
        Name = "File Plugin",
        PublisherUrl = "http://www.JeffGaroutte.com",
        ImagePath = "page_add.png")]
    [InsertableContentSource("a File")]
    public class FilePlugin : SmartContentSource
    {
        private Boolean _compress = false;
        public FilePlugin(Boolean compress)
            : base()
        {
            _compress = compress;
        }
        public FilePlugin()
            : this(false)
        {

        }
        //XCOPY /D /Y /R "$(TargetPath)" "$(SolutionDir)..\..\System\Apps\DE5F518C-0D5F-4356-9994-B7C008D73F5C\Data\App\WindowsLiveWriter\Plugins"
        public override SmartContentEditor CreateEditor(ISmartContentEditorSite editorSite)
        {

            FileContentEditor editor = new FileContentEditor(editorSite);
            return editor;
        }

        public override DialogResult CreateContent(IWin32Window dialogOwner, ISmartContent newContent)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            // FolderBrowserDialog d = new FolderBrowserDialog();
            DialogResult result = dialog.ShowDialog();
            switch (result)
            {
                case DialogResult.OK:
                case DialogResult.Yes:
                    Settings setting = new Settings(newContent);
                    setting.Compress = _compress;
                    setting.FileName = dialog.SafeFileName;
                    if (_compress)
                    {
                        setting.FileName += ".gz";
                        FileInfo fi = new FileInfo(dialog.FileName);
                        using (FileStream inFile = fi.OpenRead())
                        using (Stream outFile = newContent.Files.Open(setting.FileName, true))
                        {
                            using (GZipStream Compress = new GZipStream(outFile,
                            CompressionMode.Compress))
                            {
                                // Copy the source file into the compression stream.
                                byte[] buffer = new byte[4096];
                                int numRead;
                                while ((numRead = inFile.Read(buffer, 0, buffer.Length)) != 0)
                                {
                                    Compress.Write(buffer, 0, numRead);
                                }
                            }
                            setting.CompressFileSize = outFile.Length.ToString();
                        }
                    }
                    else
                        newContent.Files.Add(setting.FileName, dialog.FileName);
                    break;
                case DialogResult.Abort:
                case DialogResult.Cancel:
                case DialogResult.Ignore:
                case DialogResult.No:
                case DialogResult.None:
                case DialogResult.Retry:
                default:
                    break;
            }
            return result;
        }

        public override string GeneratePublishHtml(ISmartContent content, IPublishingContext publishingContext)
        {
            Settings settings = new Settings(content);
            StringBuilder result = new StringBuilder();
            result.AppendFormat("<a href=\"{0}\"", content.Files.GetUri(content.Files.Filenames[0]));
            string className = settings.ClassName;
            if (!String.IsNullOrEmpty(className))
                result.AppendFormat(" class=\"{0}\"", className);
            string fileName = settings.FileName;
            if (String.IsNullOrEmpty(fileName))
                fileName = content.Files.Filenames[0];
            result.Append(">");
            result.Append(fileName);
            result.Append("</a>");
            return result.ToString();
        }
    }
}
